@@ -97,10 +97,11 @@ impl OcflRepo {
         prefix: Option<&str>,
         staging_root: impl AsRef<Path>,
         layout: Option<StorageLayout>,
+        profile: Option<&str>,
     ) -> Result<Self> {
         Ok(Self {
             staging_root: staging_root.as_ref().to_path_buf(),
-            store: Box::new(S3OcflStore::init(region, bucket, prefix, layout)?),
+            store: Box::new(S3OcflStore::init(region, bucket, prefix, layout, profile)?),
             staging: OnceCell::default(),
             staging_lock_manager: OnceCell::default(),
             use_backslashes: false,
@@ -116,10 +117,11 @@ impl OcflRepo {
         bucket: &str,
         prefix: Option<&str>,
         staging_root: impl AsRef<Path>,
+        profile: Option<&str>,
     ) -> Result<Self> {
         Ok(Self {
             staging_root: staging_root.as_ref().to_path_buf(),
-            store: Box::new(S3OcflStore::new(region, bucket, prefix)?),
+            store: Box::new(S3OcflStore::new(region, bucket, prefix, profile)?),
             staging: OnceCell::default(),
             staging_lock_manager: OnceCell::default(),
             use_backslashes: false,
